#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include <stdarg.h>
#include <string.h>

const char       * g_Lang = "CZE";
#define THRESHOLD 1e-10

/*-----------------------------------------------------------------------------------------------*/
const char       * ChooseString                            ( const char      * Lang,
                                                             const char      * String,
                                                             ... )
 {
   va_list va;
   const char * Backup = String;

   va_start ( va, String );
   while ( 1 )
    {
      if ( ! Lang ) break;
      if ( ! strcmp ( Lang, g_Lang ) )
       {
         va_end ( va );
         return ( String );
       }
      Lang = va_arg ( va, const char * );
      String = va_arg ( va, const char * );
    }
   va_end ( va );
   return ( Backup );
 }
/*-----------------------------------------------------------------------------------------------*/
static void        printAngle                              ( const char      * legend, 
                                                             double            angle )
 {
   int    sec = (int)(angle * 180.0 / M_PI * 360000 + 0.5);

   printf ( "%s: %.4f rad = %d %s %02d'%02d.%02d''\n", legend, angle, 
                                                    sec / 360000, ChooseString ( "CZE", "s", "ENG", "deg", NULL ), 
                                                    (sec / 6000 ) % 60,
                                                    (sec / 100 ) % 60,
                                                    sec % 100 );
 }
/*-----------------------------------------------------------------------------------------------*/
int                main                                    ( int               argc, 
                                                             char            * argv[] )
 {
   double a, b, c, S, s, a2, b2, c2;
   double alpha, beta, gamma;


   if ( argc > 1 ) g_Lang = argv[1];

   printf ( ChooseString ( "CZE", "Zadejte velikost stran a b c:\n",
                           "ENG", "Enter lengths a, b, and c:\n", 
                           NULL ));

   if ( scanf ( "%lf %lf %lf", &a, &b, &c ) != 3 || a <= 0 || b <= 0 || c <= 0 )
    {
      printf ( ChooseString ( "CZE", "Nespravny vstup.\n",
                              "ENG", "Invalid input.\n",
                              NULL ) );
      return ( 1 );
    }

   if ( ( a + b <= c ) || ( fabs ( a - b ) >= c ) )
    {
      printf ( ChooseString ( "CZE", "Trojuhelnik neexistuje.\n",
                              "ENG", "The triangle does not exist.\n",
                              NULL ));
      return ( 1 );
    }

   printf ( ChooseString ( "CZE", "Trojuhelnik ", 
                           "ENG", "The triangle ",
                           NULL ) );

   if ( a == b && a == c )
     printf ( ChooseString ( "CZE", "je rovnostranny.\n",
                             "ENG", "is equilateral.\n",
                             NULL ));
    else if ( a == b || a == c || c == b )
     printf ( ChooseString ( "CZE", "je rovnoramenny.\n",
                             "ENG", "is isosceles.\n",
                             NULL ));
    else
     printf ( ChooseString ( "CZE", "neni ani rovnostranny ani rovnoramenny.\n",
                             "ENG", "is scalene.\n",
                             NULL ));

   c2 = c * c;
   b2 = b * b;
   a2 = a * a;

   printf ( ChooseString ( "CZE", "Trojuhelnik je ", 
                           "ENG", "The triangle is ",
                           NULL ) );
   if ( fabs ( a2 + b2 - c2 ) < THRESHOLD * c2 || 
        fabs ( a2 + c2 - b2 ) < THRESHOLD * b2 || 
        fabs ( c2 + b2 - a2 ) < THRESHOLD * a2 )
     printf ( ChooseString ( "CZE", "pravouhly.\n",
                             "ENG", "a right triangle.\n",
                             NULL ) );
    else if ( c2 > a2 + b2 || b2 > a2 + c2 || a2 > c2 + b2 )
     printf ( ChooseString ( "CZE", "tupouhly.\n",
                             "ENG", "obtuse.\n",
                             NULL ) );
    else 
     printf ( ChooseString ( "CZE", "ostrouhly.\n",
                             "ENG", "acute.\n",
                             NULL ) );


   /* z kosinove vety */
   alpha = acos ( (c * c + b * b - a * a ) / ( 2 * c * b ) );
   beta  = acos ( (a * a + c * c - b * b ) / ( 2 * a * c ) );
   gamma = acos ( (a * a + b * b - c * c ) / ( 2 * a * b ) );

   printAngle ( ChooseString ( "CZE", "Uhel alfa", 
                               "ENG", "Angle alpha", 
                               NULL ), alpha );
   printAngle ( ChooseString ( "CZE", "Uhel beta", 
                               "ENG", "Angle beta", 
                               NULL ), beta );
   printAngle ( ChooseString ( "CZE", "Uhel gama", 
                               "ENG", "Angle gamma", 
                               NULL ), gamma );

   printf ( ChooseString ( "CZE", "Obvod: %.4f\n", 
                           "ENG", "Perimeter: %.4f\n",
                           NULL ), a + b + c );

   
   /* Heronuv vzorec */
   s      = ( a + b + c ) / 2;
   S      = sqrt ( ( s - a ) * ( s - b ) * ( s - c ) * s );
   printf ( ChooseString ( "CZE", "Obsah: %.4f\n",
                           "ENG", "Area: %.4f\n",
                           NULL ), S );
   printf ( ChooseString ( "CZE", "Polomer kruznice vepsane: %.4f\n",
                           "ENG", "Inradius: %.4f\n",
                           NULL ), S / s );
   printf ( ChooseString ( "CZE", "Polomer kruznice opsane: %.4f\n",
                           "ENG", "Circumradius: %.4f\n",
                           NULL ), 0.25 * a * b * c / S );
   
   printf ( ChooseString ( "CZE", "Vyska va: %.4f\n",
                           "ENG", "Altitude a: %.4f\n",
                           NULL ), 2 * S / a );
   printf ( ChooseString ( "CZE", "Vyska vb: %.4f\n",
                           "ENG", "Altitude b: %.4f\n",
                           NULL ), 2 * S / b );
   printf ( ChooseString ( "CZE", "Vyska vc: %.4f\n",
                           "ENG", "Altitude c: %.4f\n",
                           NULL ), 2 * S / c );
   return ( 0 );
 }

